package com.ruoyi.abuwx.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.abuwx.vo.BannerInfoVo;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.abuwx.domain.BannerInfo;
import com.ruoyi.abuwx.service.IBannerInfoService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 轮播图管理Controller
 *
 * @author lujie
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/banner/info")
public class BannerInfoController extends BaseController
{
    @Autowired
    private IBannerInfoService bannerInfoService;

    /**
     * 查询轮播图管理列表
     */
    @PreAuthorize("@ss.hasPermi('banner:info:list')")
    @GetMapping("/list")
    public TableDataInfo list(BannerInfo bannerInfo)
    {
        startPage();
        List<BannerInfoVo> list = bannerInfoService.selectBannerInfoVoList(bannerInfo);


        return getDataTable(list);
    }

    /**
     * 导出轮播图管理列表
     */
    @PreAuthorize("@ss.hasPermi('banner:info:export')")
    @Log(title = "轮播图管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BannerInfo bannerInfo)
    {
        List<BannerInfo> list = bannerInfoService.selectBannerInfoList(bannerInfo);
        ExcelUtil<BannerInfo> util = new ExcelUtil<BannerInfo>(BannerInfo.class);
        util.exportExcel(response, list, "轮播图管理数据");
    }

    /**
     * 获取轮播图管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('banner:info:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(bannerInfoService.selectBannerInfoById(id));
    }

    /**
     * 新增轮播图管理
     */
    @PreAuthorize("@ss.hasPermi('banner:info:add')")
    @Log(title = "轮播图管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BannerInfo bannerInfo)
    {
        return toAjax(bannerInfoService.insertBannerInfo(bannerInfo));
    }

    /**
     * 修改轮播图管理
     */
    @PreAuthorize("@ss.hasPermi('banner:info:edit')")
    @Log(title = "轮播图管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BannerInfo bannerInfo)
    {
        return toAjax(bannerInfoService.updateBannerInfo(bannerInfo));
    }

    /**
     * 删除轮播图管理
     */
    @PreAuthorize("@ss.hasPermi('banner:info:remove')")
    @Log(title = "轮播图管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(bannerInfoService.deleteBannerInfoByIds(ids));
    }
}
