package com.ruoyi.abuwx.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.abuwx.domain.InfoCategory;
import com.ruoyi.abuwx.service.IInfoCategoryService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 资讯类别Controller
 *
 * @author lujie
 * @date 2024-12-19
 */
@RestController
@RequestMapping("/info/category")
public class InfoCategoryController extends BaseController
{
    @Autowired
    private IInfoCategoryService infoCategoryService;

    /**
     * 查询资讯类别列表
     */
    @PreAuthorize("@ss.hasPermi('info:category:list')")
    @GetMapping("/list")
    public TableDataInfo list(InfoCategory infoCategory)
    {
        startPage();
        List<InfoCategory> list = infoCategoryService.selectInfoCategoryList(infoCategory);
        return getDataTable(list);
    }

    /**
     * 导出资讯类别列表
     */
    @PreAuthorize("@ss.hasPermi('abuwx:category:export')")
    @Log(title = "资讯类别", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, InfoCategory infoCategory)
    {
        List<InfoCategory> list = infoCategoryService.selectInfoCategoryList(infoCategory);
        ExcelUtil<InfoCategory> util = new ExcelUtil<InfoCategory>(InfoCategory.class);
        util.exportExcel(response, list, "资讯类别数据");
    }

    /**
     * 获取资讯类别详细信息
     */
    @PreAuthorize("@ss.hasPermi('abuwx:category:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(infoCategoryService.selectInfoCategoryById(id));
    }

    /**
     * 新增资讯类别
     */
    @PreAuthorize("@ss.hasPermi('abuwx:category:add')")
    @Log(title = "资讯类别", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody InfoCategory infoCategory)
    {
        return toAjax(infoCategoryService.insertInfoCategory(infoCategory));
    }

    /**
     * 修改资讯类别
     */
    @PreAuthorize("@ss.hasPermi('abuwx:category:edit')")
    @Log(title = "资讯类别", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody InfoCategory infoCategory)
    {
        return toAjax(infoCategoryService.updateInfoCategory(infoCategory));
    }

    /**
     * 删除资讯类别
     */
    @PreAuthorize("@ss.hasPermi('abuwx:category:remove')")
    @Log(title = "资讯类别", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(infoCategoryService.deleteInfoCategoryByIds(ids));
    }
}
