package com.ruoyi.abuwx.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.abuwx.domain.InfoOerationRecords;
import com.ruoyi.abuwx.service.IInfoOerationRecordsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 资讯信息操作记录Controller
 * 
 * @author lujie
 * @date 2024-12-27
 */
@RestController
@RequestMapping("/info/records")
public class InfoOerationRecordsController extends BaseController
{
    @Autowired
    private IInfoOerationRecordsService infoOerationRecordsService;

    /**
     * 查询资讯信息操作记录列表
     */
    @PreAuthorize("@ss.hasPermi('info:records:list')")
    @GetMapping("/list")
    public TableDataInfo list(InfoOerationRecords infoOerationRecords)
    {
        startPage();
        List<InfoOerationRecords> list = infoOerationRecordsService.selectInfoOerationRecordsList(infoOerationRecords);
        return getDataTable(list);
    }

    /**
     * 导出资讯信息操作记录列表
     */
    @PreAuthorize("@ss.hasPermi('info:records:export')")
    @Log(title = "资讯信息操作记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, InfoOerationRecords infoOerationRecords)
    {
        List<InfoOerationRecords> list = infoOerationRecordsService.selectInfoOerationRecordsList(infoOerationRecords);
        ExcelUtil<InfoOerationRecords> util = new ExcelUtil<InfoOerationRecords>(InfoOerationRecords.class);
        util.exportExcel(response, list, "资讯信息操作记录数据");
    }

    /**
     * 获取资讯信息操作记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('info:records:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(infoOerationRecordsService.selectInfoOerationRecordsById(id));
    }

    /**
     * 新增资讯信息操作记录
     */
    @PreAuthorize("@ss.hasPermi('info:records:add')")
    @Log(title = "资讯信息操作记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody InfoOerationRecords infoOerationRecords)
    {
        return toAjax(infoOerationRecordsService.insertInfoOerationRecords(infoOerationRecords));
    }

    /**
     * 修改资讯信息操作记录
     */
    @PreAuthorize("@ss.hasPermi('info:records:edit')")
    @Log(title = "资讯信息操作记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody InfoOerationRecords infoOerationRecords)
    {
        return toAjax(infoOerationRecordsService.updateInfoOerationRecords(infoOerationRecords));
    }

    /**
     * 删除资讯信息操作记录
     */
    @PreAuthorize("@ss.hasPermi('info:records:remove')")
    @Log(title = "资讯信息操作记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(infoOerationRecordsService.deleteInfoOerationRecordsByIds(ids));
    }
}
