package com.ruoyi.abuwx.service.impl;

import com.ruoyi.abuwx.domain.BannerInfo;
import com.ruoyi.abuwx.domain.InfoContent;
import com.ruoyi.abuwx.mapper.BannerInfoMapper;
import com.ruoyi.abuwx.mapper.InfoContentMapper;
import com.ruoyi.abuwx.service.IBannerInfoService;
import com.ruoyi.abuwx.vo.BannerInfoVo;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * 轮播图管理Service业务层处理
 *
 * @author lujie
 * @date 2024-12-26
 */
@Service
public class BannerInfoServiceImpl implements IBannerInfoService
{
    @Autowired
    private BannerInfoMapper bannerInfoMapper;
    @Autowired
    private InfoContentMapper infoContentMapper;

    /**
     * 查询轮播图管理
     *
     * @param id 轮播图管理主键
     * @return 轮播图管理
     */
    @Override
    public BannerInfo selectBannerInfoById(Long id)
    {
        return bannerInfoMapper.selectBannerInfoById(id);
    }

    /**
     * 查询轮播图管理列表
     *
     * @param bannerInfo 轮播图管理
     * @return 轮播图管理
     */
    @Override
    public List<BannerInfo> selectBannerInfoList(BannerInfo bannerInfo)
    {
        return bannerInfoMapper.selectBannerInfoList(bannerInfo);
    }

    /**
     * 新增轮播图管理
     *
     * @param bannerInfo 轮播图管理
     * @return 结果
     */
    @Override
    public int insertBannerInfo(BannerInfo bannerInfo)
    {
        bannerInfo.setCreateTime(DateUtils.getNowDate());
        return bannerInfoMapper.insertBannerInfo(bannerInfo);
    }

    /**
     * 修改轮播图管理
     *
     * @param bannerInfo 轮播图管理
     * @return 结果
     */
    @Override
    public int updateBannerInfo(BannerInfo bannerInfo)
    {
        bannerInfo.setUpdateTime(DateUtils.getNowDate());
        return bannerInfoMapper.updateBannerInfo(bannerInfo);
    }

    /**
     * 批量删除轮播图管理
     *
     * @param ids 需要删除的轮播图管理主键
     * @return 结果
     */
    @Override
    public int deleteBannerInfoByIds(Long[] ids)
    {
        return bannerInfoMapper.deleteBannerInfoByIds(ids);
    }

    /**
     * 删除轮播图管理信息
     *
     * @param id 轮播图管理主键
     * @return 结果
     */
    @Override
    public int deleteBannerInfoById(Long id)
    {
        return bannerInfoMapper.deleteBannerInfoById(id);
    }

    @Override
    public List<BannerInfoVo> selectBannerInfoVoList(BannerInfo bannerInfo) {
        List<BannerInfoVo> bannerInfoVoList = new ArrayList<>();
        List<BannerInfo> list = bannerInfoMapper.selectBannerInfoList(bannerInfo);
        list.forEach(item->{
            Long infoId = item.getInfoId();
            InfoContent infoContent = infoContentMapper.selectInfoContentById(infoId);
            String infoTitle = infoContent.getTitle();
            BannerInfoVo bannerInfoVo = new BannerInfoVo();
            BeanUtils.copyProperties(item, bannerInfoVo);
            bannerInfoVo.setInfoTitle(infoTitle);
            bannerInfoVoList.add(bannerInfoVo);
        });
        return bannerInfoVoList;
    }
}
