package com.ruoyi.abuwx.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.abuwx.mapper.VideoContentMapper;
import com.ruoyi.abuwx.domain.VideoContent;
import com.ruoyi.abuwx.service.IVideoContentService;

/**
 * 视频信息Service业务层处理
 * 
 * @author lujie
 * @date 2024-12-20
 */
@Service
public class VideoContentServiceImpl implements IVideoContentService 
{
    @Autowired
    private VideoContentMapper videoContentMapper;

    /**
     * 查询视频信息
     * 
     * @param id 视频信息主键
     * @return 视频信息
     */
    @Override
    public VideoContent selectVideoContentById(Long id)
    {
        return videoContentMapper.selectVideoContentById(id);
    }

    /**
     * 查询视频信息列表
     * 
     * @param videoContent 视频信息
     * @return 视频信息
     */
    @Override
    public List<VideoContent> selectVideoContentList(VideoContent videoContent)
    {
        return videoContentMapper.selectVideoContentList(videoContent);
    }

    /**
     * 新增视频信息
     * 
     * @param videoContent 视频信息
     * @return 结果
     */
    @Override
    public int insertVideoContent(VideoContent videoContent)
    {
        videoContent.setCreateTime(DateUtils.getNowDate());
        return videoContentMapper.insertVideoContent(videoContent);
    }

    /**
     * 修改视频信息
     * 
     * @param videoContent 视频信息
     * @return 结果
     */
    @Override
    public int updateVideoContent(VideoContent videoContent)
    {
        videoContent.setUpdateTime(DateUtils.getNowDate());
        return videoContentMapper.updateVideoContent(videoContent);
    }

    /**
     * 批量删除视频信息
     * 
     * @param ids 需要删除的视频信息主键
     * @return 结果
     */
    @Override
    public int deleteVideoContentByIds(Long[] ids)
    {
        return videoContentMapper.deleteVideoContentByIds(ids);
    }

    /**
     * 删除视频信息信息
     * 
     * @param id 视频信息主键
     * @return 结果
     */
    @Override
    public int deleteVideoContentById(Long id)
    {
        return videoContentMapper.deleteVideoContentById(id);
    }
}
